Chime class

Main plugin class

Constructors

Chime()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

eventChannel → EventChannel
The event channel you can subscribe to with Chime.eventChannel.receiveBroadcastStream().listen()
no setter
version → Future<String?>
The version of the used Amazon Chime SDK.
no setter

Static Methods

audioVideoStart() → Future<String?>
Starts audio and video (get ready to receive and send audio and video).
audioVideoStartLocalVideo() → Future<String?>
Starts local video.
audioVideoStartRemoteVideo() → Future<String?>
Starts all remote videos.
audioVideoStop() → Future<String?>
Stops audio and video.
audioVideoStopLocalVideo() → Future<String?>
Stops local video.
audioVideoStopRemoteVideo() → Future<String?>
Stops all remote videos.
bindVideoView(int viewId, int tileId) → Future<String?>
Binds a view to a video tile.
chooseAudioDevice(String label) → Future<String?>
Chooses a device by label.
clearViewIds() → Future<String?>
Clears all view ids of the ChimeDefaultVideoRenderViewFactory.
createMeetingSession({required String meetingId, required String externalMeetingId, required String mediaRegion, required String mediaPlacementAudioHostUrl, required String mediaPlacementAudioFallbackUrl, required String mediaPlacementSignalingUrl, required String mediaPlacementTurnControlUrl, required String attendeeId, required String externalUserId, required String joinToken}) → Future<String?>
Creates a meeting session.
listAudioDevices() → Future<String?>
Lists all available audio devices.
mute() → Future<String?>
Mutes local audio.
unbindVideoView(int tileId) → Future<String?>
Unbinds a video tile.
unmute() → Future<String?>
Unmutes local audio.